@@ -30,6 +30,7 @@ CANCEL_ORDER_HASH = '0x45170c4ba6a19e3c9e25a4f3b3d65b9f2d988ad80f7a270528c03a7c4
 ORDER_SIGNATURE = '0x94c3e787666fa8d2611ce4543ced732e0f4591958d8a12feded84746bcde457f1dab3fc66cafc5eda9c6e755f0f82f4049353cad165a5187d4ec66d365c9c2991b01'  # noqa: E501
 CANCEL_ORDER_SIGNATURE = '0x3d29b75f6aad6db4cc02259bcaa98f465a164392b1c4743d7d0f53b73f64f29f00b495dc132b9a63b4aa613c15909878be1274b575549a959d9586eb7b5e520a1b01'  # noqa: E501
 PAIRS = ['WETH-DAI', 'DAI-WETH']
+MARKETS = ['WETH-DAI']
 LOCAL_NODE = 'http://0.0.0.0:8545'
 
 
@@ -181,19 +182,33 @@ class TestClient():
         client = Client(PRIVATE_KEY_1)
         with pytest.raises(TypeError) as error:
             client.get_my_orders()
-        assert 'required positional argument: \'pairs\'' in str(error.value)
+        assert 'required positional argument: \'market\'' in str(error.value)
+
+    def test_get_orders_no_market_success(self):
+        client = Client(PRIVATE_KEY_1)
+        with requests_mock.mock() as rm:
+            json_obj = tests.test_json.mock_get_orders_json
+            uri = 'https://api.dydx.exchange/v2/orders' \
+                + '?accountOwner=' + client.public_address \
+                + '&accountNumber=' + str(client.account_number)
+            rm.get(uri, json=json_obj)
+            result = client.get_orders(
+                accountOwner=client.public_address,
+                accountNumber=client.account_number,
+            )
+            assert result == json_obj
 
     def test_get_my_orders_default_success(self):
         client = Client(PRIVATE_KEY_1)
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_orders_json
-            uri = 'https://api.dydx.exchange/v1/dex/orders' \
-                + '?makerAccountOwner=' + client.public_address \
-                + '&makerAccountNumber=' + str(client.account_number) \
-                + '&pairs=' + ','.join(PAIRS)
+            uri = 'https://api.dydx.exchange/v2/orders' \
+                + '?accountOwner=' + client.public_address \
+                + '&accountNumber=' + str(client.account_number) \
+                + '&market=' + ','.join(MARKETS)
             rm.get(uri, json=json_obj)
             result = client.get_my_orders(
-                pairs=PAIRS
+                market=MARKETS,
             )
             assert result == json_obj
 
@@ -203,15 +218,15 @@ class TestClient():
         startingBefore = datetime.datetime.utcnow().isoformat()
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_orders_json
-            uri = 'https://api.dydx.exchange/v1/dex/orders' \
-                + '?makerAccountOwner=' + client.public_address \
-                + '&makerAccountNumber=' + str(client.account_number) \
-                + '&pairs=' + ','.join(PAIRS) \
+            uri = 'https://api.dydx.exchange/v2/orders' \
+                + '?accountOwner=' + client.public_address \
+                + '&accountNumber=' + str(client.account_number) \
+                + '&market=' + ','.join(MARKETS) \
                 + '&limit=' + str(limit) \
                 + '&startingBefore=' + startingBefore
             rm.get(uri, json=json_obj)
             result = client.get_my_orders(
-                pairs=PAIRS,
+                market=MARKETS,
                 limit=limit,
                 startingBefore=startingBefore
             )
@@ -219,21 +234,15 @@ class TestClient():
 
     # ------------ get_orders ------------
 
-    def test_get_orders_no_pairs_error(self):
-        client = Client(PRIVATE_KEY_1)
-        with pytest.raises(TypeError) as error:
-            client.get_orders()
-        assert 'required positional argument: \'pairs\'' in str(error.value)
-
     def test_get_orders_default_success(self):
         client = Client(PRIVATE_KEY_1)
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_orders_json
-            uri = 'https://api.dydx.exchange/v1/dex/orders' \
-                + '?pairs=' + ','.join(PAIRS)
+            uri = 'https://api.dydx.exchange/v2/orders' \
+                + '?market=' + ','.join(MARKETS)
             rm.get(uri, json=json_obj)
             result = client.get_orders(
-                pairs=PAIRS
+                market=MARKETS,
             )
             assert result == json_obj
 
@@ -243,13 +252,13 @@ class TestClient():
         startingBefore = datetime.datetime.utcnow().isoformat()
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_orders_json
-            uri = 'https://api.dydx.exchange/v1/dex/orders' \
-                + '?pairs=' + ','.join(PAIRS) \
+            uri = 'https://api.dydx.exchange/v2/orders' \
+                + '?market=' + ','.join(MARKETS) \
                 + '&limit=' + str(limit) \
                 + '&startingBefore=' + startingBefore
             rm.get(uri, json=json_obj)
             result = client.get_orders(
-                pairs=PAIRS,
+                market=MARKETS,
                 limit=limit,
                 startingBefore=startingBefore
             )
@@ -261,7 +270,7 @@ class TestClient():
         client = Client(PRIVATE_KEY_1)
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_order_json
-            uri = 'https://api.dydx.exchange/v1/dex/orders/' \
+            uri = 'https://api.dydx.exchange/v2/orders/' \
                 + ORDER_HASH
             rm.get(uri, json=json_obj)
             result = client.get_order(
@@ -275,19 +284,19 @@ class TestClient():
         client = Client(PRIVATE_KEY_1)
         with pytest.raises(TypeError) as error:
             client.get_my_fills()
-        assert 'required positional argument: \'pairs\'' in str(error.value)
+        assert 'required positional argument: \'market\'' in str(error.value)
 
     def test_get_my_fills_default_success(self):
         client = Client(PRIVATE_KEY_1)
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_fills_json
-            uri = 'https://api.dydx.exchange/v1/dex/fills' \
-                + '?makerAccountOwner=' + client.public_address \
-                + '&makerAccountNumber=' + str(client.account_number) \
-                + '&pairs=' + ','.join(PAIRS)
+            uri = 'https://api.dydx.exchange/v2/fills' \
+                + '?accountOwner=' + client.public_address \
+                + '&accountNumber=' + str(client.account_number) \
+                + '&market=' + ','.join(MARKETS)
             rm.get(uri, json=json_obj)
             result = client.get_my_fills(
-                pairs=PAIRS
+                market=MARKETS
             )
             assert result == json_obj
 
@@ -297,15 +306,15 @@ class TestClient():
         startingBefore = datetime.datetime.utcnow().isoformat()
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_fills_json
-            uri = 'https://api.dydx.exchange/v1/dex/fills' \
-                + '?makerAccountOwner=' + client.public_address \
-                + '&makerAccountNumber=' + str(client.account_number) \
-                + '&pairs=' + ','.join(PAIRS) \
+            uri = 'https://api.dydx.exchange/v2/fills' \
+                + '?accountOwner=' + client.public_address \
+                + '&accountNumber=' + str(client.account_number) \
+                + '&market=' + ','.join(MARKETS) \
                 + '&limit=' + str(limit) \
                 + '&startingBefore=' + startingBefore
             rm.get(uri, json=json_obj)
             result = client.get_my_fills(
-                pairs=PAIRS,
+                market=MARKETS,
                 limit=limit,
                 startingBefore=startingBefore
             )
@@ -313,21 +322,15 @@ class TestClient():
 
     # ------------ get_fills ------------
 
-    def test_get_fills_no_pairs_error(self):
-        client = Client(PRIVATE_KEY_1)
-        with pytest.raises(TypeError) as error:
-            client.get_fills()
-        assert 'required positional argument: \'pairs\'' in str(error.value)
-
     def test_get_fills_default_success(self):
         client = Client(PRIVATE_KEY_1)
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_fills_json
-            uri = 'https://api.dydx.exchange/v1/dex/fills' \
-                + '?pairs=' + ','.join(PAIRS)
+            uri = 'https://api.dydx.exchange/v2/fills' \
+                + '?market=' + ','.join(MARKETS)
             rm.get(uri, json=json_obj)
             result = client.get_fills(
-                pairs=PAIRS
+                market=MARKETS,
             )
             assert result == json_obj
 
@@ -337,13 +340,13 @@ class TestClient():
         startingBefore = datetime.datetime.utcnow().isoformat()
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_fills_json
-            uri = 'https://api.dydx.exchange/v1/dex/fills' \
-                + '?pairs=' + ','.join(PAIRS) \
+            uri = 'https://api.dydx.exchange/v2/fills' \
+                + '?market=' + ','.join(MARKETS) \
                 + '&limit=' + str(limit) \
                 + '&startingBefore=' + startingBefore
             rm.get(uri, json=json_obj)
             result = client.get_fills(
-                pairs=PAIRS,
+                market=MARKETS,
                 limit=limit,
                 startingBefore=startingBefore
             )
@@ -355,37 +358,37 @@ class TestClient():
         client = Client(PRIVATE_KEY_1)
         with pytest.raises(TypeError) as error:
             client.get_my_trades()
-        assert 'required positional argument: \'pairs\'' in str(error.value)
+        assert 'required positional argument: \'market\'' in str(error.value)
 
     def test_get_my_trades_default_success(self):
         client = Client(PRIVATE_KEY_1)
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_trades_json
-            uri = 'https://api.dydx.exchange/v1/dex/trades' \
-                + '?makerAccountOwner=' + client.public_address \
-                + '&makerAccountNumber=' + str(client.account_number) \
-                + '&pairs=' + ','.join(PAIRS)
+            uri = 'https://api.dydx.exchange/v2/trades' \
+                + '?accountOwner=' + client.public_address \
+                + '&accountNumber=' + str(client.account_number) \
+                + '&market=' + ','.join(MARKETS)
             rm.get(uri, json=json_obj)
             result = client.get_my_trades(
-                pairs=PAIRS
+                market=MARKETS,
             )
             assert result == json_obj
 
     def test_get_my_trades_specified_success(self):
         client = Client(PRIVATE_KEY_1)
-        limit = 1234
+        limit = 99
         startingBefore = datetime.datetime.utcnow().isoformat()
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_trades_json
-            uri = 'https://api.dydx.exchange/v1/dex/trades' \
-                + '?makerAccountOwner=' + client.public_address \
-                + '&makerAccountNumber=' + str(client.account_number) \
-                + '&pairs=' + ','.join(PAIRS) \
+            uri = 'https://api.dydx.exchange/v2/trades' \
+                + '?accountOwner=' + client.public_address \
+                + '&accountNumber=' + str(client.account_number) \
+                + '&market=' + ','.join(MARKETS) \
                 + '&limit=' + str(limit) \
                 + '&startingBefore=' + startingBefore
             rm.get(uri, json=json_obj)
             result = client.get_my_trades(
-                pairs=PAIRS,
+                market=MARKETS,
                 limit=limit,
                 startingBefore=startingBefore
             )
@@ -393,21 +396,15 @@ class TestClient():
 
     # ------------ get_trades ------------
 
-    def test_get_trades_no_pairs_error(self):
-        client = Client(PRIVATE_KEY_1)
-        with pytest.raises(TypeError) as error:
-            client.get_trades()
-        assert 'required positional argument: \'pairs\'' in str(error.value)
-
     def test_get_trades_default_success(self):
         client = Client(PRIVATE_KEY_1)
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_trades_json
-            uri = 'https://api.dydx.exchange/v1/dex/trades' \
-                + '?pairs=' + ','.join(PAIRS)
+            uri = 'https://api.dydx.exchange/v2/trades' \
+                + '?market=' + ','.join(MARKETS)
             rm.get(uri, json=json_obj)
             result = client.get_trades(
-                pairs=PAIRS
+                market=MARKETS,
             )
             assert result == json_obj
 
@@ -417,13 +414,13 @@ class TestClient():
         startingBefore = datetime.datetime.utcnow().isoformat()
         with requests_mock.mock() as rm:
             json_obj = tests.test_json.mock_get_trades_json
-            uri = 'https://api.dydx.exchange/v1/dex/trades' \
-                + '?pairs=' + ','.join(PAIRS) \
+            uri = 'https://api.dydx.exchange/v2/trades' \
+                + '?market=' + ','.join(MARKETS) \
                 + '&limit=' + str(limit) \
                 + '&startingBefore=' + startingBefore
             rm.get(uri, json=json_obj)
             result = client.get_trades(
-                pairs=PAIRS,
+                market=MARKETS,
                 limit=limit,
                 startingBefore=startingBefore
             )
